% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      scdist5
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the domain
[phi,theta,r ] = meshgrid(linspace(0,2*pi,41),linspace(0,2*pi,41),linspace(0,1,41));
[x,y,z] = sph2cart(phi,theta,r);
% plot the desired state
figure(1); clf; hold on
val = yd(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('desired state y_{d}');
view(3);

% plot the state constraints
figure(2); clf; hold on
val = yc(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('lower state constraint y_{c}');
view(3);

% plot the right hand side 
figure(3); clf; hold on
val = f(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('right hand side f');
view(3);

% plot the optimal state 
figure(4); clf; hold on
val = supplementary_y(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('optimal state');
view(3);

% plot the optimal adjoint 
figure(5); clf; hold on
val = supplementary_p(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('adjoint');
view(3);

% plot the optimal control 
figure(6); clf; hold on
val = supplementary_u(problem,x,y,z);
scatter3(x(:),y(:),z(:),[],val(:),'.');
xlabel('x');
ylabel('y');
zlabel('z');
title('adjoint');
view(3);

